@@ -9,7 +9,7 @@ use 5.006;
 
 use vars (qw($VERSION $Tolerance $Min_samples_number));
 
-$VERSION = '3.0610';
+$VERSION = '3.0611';
 
 $Tolerance = 0.0;
 $Min_samples_number = 4;
@@ -18,7 +18,7 @@ package Statistics::Descriptive::Sparse;
 
 use vars qw($VERSION);
 
-$VERSION = '3.0610';
+$VERSION = '3.0611';
 
 use vars qw(%fields);
 use Carp;
@@ -238,7 +238,7 @@ package Statistics::Descriptive::Full;
 
 use vars qw($VERSION);
 
-$VERSION = '3.0610';
+$VERSION = '3.0611';
 
 use Carp;
 use POSIX ();
@@ -1204,7 +1204,8 @@ then the standard deviation will be high enough to make neither case an outlier.
 
 Set the function to filter out the outlier.
 
-C<$code_ref> is the reference to the subroutine implemeting the filtering function.
+C<$code_ref> is the reference to the subroutine implementing the filtering
+function.
 
 Returns C<undef> for invalid values of C<$code_ref> (i.e.: not defined or not a
 code reference), C<1> otherwise.
